@@ -1,7 +1,7 @@
 require "spec_helper"
 
 RSpec.describe MiniMagick::Tool do
-  subject { MiniMagick::Tool::Identify.new }
+  subject { MiniMagick.identify }
 
   describe "#call" do
     it "calls the shell to run the command" do
@@ -36,11 +36,6 @@ RSpec.describe MiniMagick::Tool do
       end
       expect(output).to match("GIF")
     end
-
-    it "defaults whiny to MiniMagick.whiny" do
-      allow(MiniMagick).to receive(:whiny).and_return(false)
-      expect(subject.instance_variable_get("@whiny")).to eq false
-    end
   end
 
   describe "#command" do
@@ -51,31 +46,26 @@ RSpec.describe MiniMagick::Tool do
   end
 
   describe "#executable" do
-    it "prepends 'gm' to the command list when using GraphicsMagick" do
-      allow(MiniMagick).to receive(:cli).and_return(:graphicsmagick)
-      expect(subject.executable).to eq %W[gm identify]
-    end
-
-    it "prepends 'magick' to the command list when using ImageMagick 7" do
-      allow(MiniMagick).to receive(:cli).and_return(:imagemagick7)
+    it "prepends 'magick' to the command when using ImageMagick 7" do
+      allow(MiniMagick).to receive(:imagemagick7?).and_return(true)
       expect(subject.executable).to eq %W[magick identify]
-      expect(MiniMagick::Tool::Magick.new.executable).to eq %W[magick]
+      expect(MiniMagick.convert.executable).to eq %W[magick]
     end
 
-    it "respects #cli_path" do
-      allow(MiniMagick).to receive(:cli).and_return(:imagemagick)
-      allow(MiniMagick).to receive(:cli_path).and_return("path/to/cli")
-      expect(subject.executable).to eq %W[path/to/cli/identify]
+    it "prepends 'gm' to the command when using GraphicsMagick" do
+      allow(MiniMagick).to receive(:graphicsmagick).and_return(true)
+      expect(subject.executable).to eq %W[gm identify]
+      expect(MiniMagick.convert.executable).to eq %W[gm convert]
     end
 
     it "respects #cli_prefix as a string" do
-      allow(MiniMagick).to receive(:cli).and_return(:imagemagick)
+      allow(MiniMagick).to receive(:imagemagick7?).and_return(false)
       allow(MiniMagick).to receive(:cli_prefix).and_return('firejail')
       expect(subject.executable).to eq %W[firejail identify]
     end
 
     it "respects #cli_prefix as an array" do
-      allow(MiniMagick).to receive(:cli).and_return(:imagemagick)
+      allow(MiniMagick).to receive(:imagemagick7?).and_return(false)
       allow(MiniMagick).to receive(:cli_prefix).and_return(['firejail', '--force'])
       expect(subject.executable).to eq %W[firejail --force identify]
     end
@@ -163,11 +153,4 @@ RSpec.describe MiniMagick::Tool do
     subject.radial_gradient.canvas "khaki"
     expect(subject.args).to eq %W[radial-gradient: canvas:khaki]
   end
-
-  it "doesn't raise errors when false is passed to the constructor" do
-    subject.help
-    subject.call(false)
-
-    MiniMagick::Tool::Identify.new(false, &:help)
-  end
 end
